@@ -16,15 +16,15 @@
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <poppler.h>
 
 #ifndef _ANNOTS_H_
-#define _ANNOTS_H_
+#    define _ANNOTS_H_
 
 G_BEGIN_DECLS
 
-GtkWidget *pgd_annots_create_widget (PopplerDocument *document);
+GtkWidget *pgd_annots_create_widget(PopplerDocument *document);
 
 G_END_DECLS
 
