@@ -1,7 +1,7 @@
 /* poppler-document.cc: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2008, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2010, 2012, 2013, 2015, 2017-2022, 2024, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2010, 2012, 2013, 2015, 2017-2022, 2024, 2025, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2006-2010, Pino Toscano <pino@kde.org>
  * Copyright (C) 2010, 2011 Hib Eris <hib@hiberis.nl>
  * Copyright (C) 2012 Koji Otani <sho@bbr.jp>
@@ -248,9 +248,8 @@ QByteArray Document::fontData(const FontInfo &fi) const
 
         Object refObj(fi.m_data->embRef);
         Object strObj = refObj.fetch(xref);
-        if (strObj.isStream()) {
+        if (strObj.isStream() && strObj.streamReset()) {
             int c;
-            strObj.streamReset();
             while ((c = strObj.streamGetChar()) != EOF) {
                 result.append((char)c);
             }
@@ -574,12 +573,12 @@ Document::PdfVersion Document::getPdfVersion() const
 
 Page *Document::page(const QString &label) const
 {
-    GooString label_g(label.toLatin1().data());
+    const GooString label_g(label.toLatin1().data());
     int index;
 
-    if (!m_doc->doc->getCatalog()->labelToIndex(&label_g, &index)) {
-        std::unique_ptr<GooString> label_ug(QStringToUnicodeGooString(label));
-        if (!m_doc->doc->getCatalog()->labelToIndex(label_ug.get(), &index)) {
+    if (!m_doc->doc->getCatalog()->labelToIndex(label_g, &index)) {
+        const std::unique_ptr<GooString> label_ug(QStringToUnicodeGooString(label));
+        if (!m_doc->doc->getCatalog()->labelToIndex(*label_ug, &index)) {
             return nullptr;
         }
     }
@@ -827,10 +826,9 @@ QStringList Document::scripts() const
     const int numScripts = catalog->numJS();
     QStringList scripts;
     for (int i = 0; i < numScripts; ++i) {
-        GooString *s = catalog->getJS(i);
-        if (s) {
+        std::string s = catalog->getJS(i);
+        if (!s.empty()) {
             scripts.append(UnicodeParsedString(s));
-            delete s;
         }
     }
     return scripts;
