@@ -102,7 +102,7 @@ static char userPassword[33] = "";
 static bool printVersion = false;
 
 static std::unique_ptr<GooString> getInfoString(Dict *infoDict, const char *key);
-static GooString *getInfoDate(Dict *infoDict, const char *key);
+static std::optional<std::string> getInfoDate(Dict *infoDict, const char *key);
 
 static char textEncName[128] = "";
 
@@ -164,7 +164,7 @@ int main(int argc, char *argv[])
     std::unique_ptr<GooString> author;
     std::unique_ptr<GooString> keywords;
     std::unique_ptr<GooString> subject;
-    GooString *date = nullptr;
+    std::optional<std::string> date;
     std::unique_ptr<GooString> htmlFileName;
     HtmlOutputDev *htmlOut = nullptr;
     SplashOutputDev *splashOut = nullptr;
@@ -243,17 +243,17 @@ int main(int argc, char *argv[])
     if (argc == 3) {
         auto tmp = std::make_unique<GooString>(argv[2]);
         if (!xml) {
-            if (tmp->getLength() >= 5) {
-                const char *p = tmp->c_str() + tmp->getLength() - 5;
+            if (tmp->size() >= 5) {
+                const char *p = tmp->c_str() + tmp->size() - 5;
                 if (!strcmp(p, ".html") || !strcmp(p, ".HTML")) {
-                    htmlFileName = std::make_unique<GooString>(tmp->c_str(), tmp->getLength() - 5);
+                    htmlFileName = std::make_unique<GooString>(tmp->c_str(), tmp->size() - 5);
                 }
             }
         } else {
-            if (tmp->getLength() >= 4) {
-                const char *p = tmp->c_str() + tmp->getLength() - 4;
+            if (tmp->size() >= 4) {
+                const char *p = tmp->c_str() + tmp->size() - 4;
                 if (!strcmp(p, ".xml") || !strcmp(p, ".XML")) {
-                    htmlFileName = std::make_unique<GooString>(tmp->c_str(), tmp->getLength() - 4);
+                    htmlFileName = std::make_unique<GooString>(tmp->c_str(), tmp->size() - 4);
                 }
             }
         }
@@ -264,9 +264,9 @@ int main(int argc, char *argv[])
         error(errCommandLine, -1, "You have to provide an output filename when reading from stdin.");
         goto error;
     } else {
-        const char *p = fileName->c_str() + fileName->getLength() - 4;
+        const char *p = fileName->c_str() + fileName->size() - 4;
         if (!strcmp(p, ".pdf") || !strcmp(p, ".PDF")) {
-            htmlFileName = std::make_unique<GooString>(fileName->c_str(), fileName->getLength() - 4);
+            htmlFileName = std::make_unique<GooString>(fileName->c_str(), fileName->size() - 4);
         } else {
             htmlFileName = fileName->copy();
         }
@@ -334,7 +334,6 @@ int main(int argc, char *argv[])
     // write text file
     htmlOut = new HtmlOutputDev(doc->getCatalog(), htmlFileName->c_str(), docTitle->c_str(), author ? author->c_str() : nullptr, keywords ? keywords->c_str() : nullptr, subject ? subject->c_str() : nullptr, date ? date->c_str() : nullptr,
                                 rawOrder, firstPage, doOutline);
-    delete date;
 
     if ((complexMode || singleHtml) && !xml && !ignore) {
         // White paper color
@@ -405,10 +404,10 @@ static std::unique_ptr<GooString> getInfoString(Dict *infoDict, const char *key)
         // Convert rawString to unicode
         if (hasUnicodeByteOrderMark(rawString->toStr())) {
             isUnicode = true;
-            unicodeLength = (obj.getString()->getLength() - 2) / 2;
+            unicodeLength = (obj.getString()->size() - 2) / 2;
         } else {
             isUnicode = false;
-            unicodeLength = obj.getString()->getLength();
+            unicodeLength = obj.getString()->size();
         }
         unicodeString = new Unicode[unicodeLength];
 
@@ -428,13 +427,12 @@ static std::unique_ptr<GooString> getInfoString(Dict *infoDict, const char *key)
     return encodedString;
 }
 
-static GooString *getInfoDate(Dict *infoDict, const char *key)
+static std::optional<std::string> getInfoDate(Dict *infoDict, const char *key)
 {
     Object obj;
     int year, mon, day, hour, min, sec, tz_hour, tz_minute;
     char tz;
     struct tm tmStruct;
-    GooString *result = nullptr;
     char buf[256];
 
     obj = infoDict->lookup(key);
@@ -453,13 +451,13 @@ static GooString *getInfoDate(Dict *infoDict, const char *key)
             tmStruct.tm_isdst = -1;
             mktime(&tmStruct); // compute the tm_wday and tm_yday fields
             if (strftime(buf, sizeof(buf), "%Y-%m-%dT%H:%M:%S+00:00", &tmStruct)) {
-                result = new GooString(buf);
+                return std::string(buf);
             } else {
-                result = new GooString(s);
+                return s->toStr();
             }
         } else {
-            result = new GooString(s);
+            return s->toStr();
         }
     }
-    return result;
+    return {};
 }
